# Python integration for TurboActivate

Python integration for [LimeLM's](https://wyday.com/limelm/) [TurboActivate library](https://wyday.com/limelm/help/using-turboactivate/). This lets you add [hardware-locked licensing (a.k.a. node-locked licensing)](https://wyday.com/limelm/help/licensing-types/#hardware-locked) to your Python app.

## Usage

We have a full example app and tutorial here: [Using TurboActivate with Python](https://wyday.com/limelm/help/using-turboactivate-with-python/)

That article shows you how to add [node-locked licensing](https://wyday.com/limelm/help/licensing-types/#hardware-locked) to your app, add [verified trials](https://wyday.com/limelm/help/trials/#verified) to your app, and how to package your Python app for distribution.